==> zio-aws-gamelift_2.12-5.20.7.1-sources.jar: zio/aws/gamelift/model/ListGameServersRequest.scala <==
package zio.aws.gamelift.model
import zio.aws.gamelift.model.primitives.{
  NonZeroAndMaxString,
  PositiveInteger,
  GameServerGroupNameOrArn
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListGameServersRequest(
    gameServerGroupName: GameServerGroupNameOrArn,
    sortOrder: Optional[zio.aws.gamelift.model.SortOrder] = Optional.Absent,
    limit: Optional[PositiveInteger] = Optional.Absent,
    nextToken: Optional[NonZeroAndMaxString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.ListGameServersRequest = {
    import ListGameServersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.ListGameServersRequest
      .builder()
      .gameServerGroupName(
        GameServerGroupNameOrArn.unwrap(gameServerGroupName): java.lang.String
      )
      .optionallyWith(sortOrder.map(value => value.unwrap))(_.sortOrder)
      .optionallyWith(
        limit.map(value => PositiveInteger.unwrap(value): Integer)
      )(_.limit)
      .optionallyWith(
        nextToken.map(value =>
          NonZeroAndMaxString.unwrap(value): java.lang.String
        )
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.ListGameServersRequest.ReadOnly =
    zio.aws.gamelift.model.ListGameServersRequest.wrap(buildAwsValue())
}
object ListGameServersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.ListGameServersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.ListGameServersRequest =
      zio.aws.gamelift.model.ListGameServersRequest(
        gameServerGroupName,
        sortOrder.map(value => value),
        limit.map(value => value),
        nextToken.map(value => value)
      )
    def gameServerGroupName: GameServerGroupNameOrArn
    def sortOrder: Optional[zio.aws.gamelift.model.SortOrder]
    def limit: Optional[PositiveInteger]
    def nextToken: Optional[NonZeroAndMaxString]
    def getGameServerGroupName: ZIO[Any, Nothing, GameServerGroupNameOrArn] =
      ZIO.succeed(gameServerGroupName)
    def getSortOrder: ZIO[Any, AwsError, zio.aws.gamelift.model.SortOrder] =
      AwsError.unwrapOptionField("sortOrder", sortOrder)
    def getLimit: ZIO[Any, AwsError, PositiveInteger] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, NonZeroAndMaxString] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.ListGameServersRequest
  ) extends zio.aws.gamelift.model.ListGameServersRequest.ReadOnly {
    override val gameServerGroupName: GameServerGroupNameOrArn =
      zio.aws.gamelift.model.primitives
        .GameServerGroupNameOrArn(impl.gameServerGroupName())
    override val sortOrder: Optional[zio.aws.gamelift.model.SortOrder] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sortOrder())
        .map(value => zio.aws.gamelift.model.SortOrder.wrap(value))
    override val limit: Optional[PositiveInteger] = zio.aws.core.internal
      .optionalFromNullable(impl.limit())
      .map(value => zio.aws.gamelift.model.primitives.PositiveInteger(value))
    override val nextToken: Optional[NonZeroAndMaxString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.nextToken())
        .map(value =>
          zio.aws.gamelift.model.primitives.NonZeroAndMaxString(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.ListGameServersRequest
  ): zio.aws.gamelift.model.ListGameServersRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-gamelift_2.13-5.17.116.2-sources.jar: zio/aws/gamelift/model/ListGameServersRequest.scala <==
package zio.aws.gamelift.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.gamelift.model.primitives.{
  NonZeroAndMaxString,
  PositiveInteger,
  GameServerGroupNameOrArn
}
import scala.jdk.CollectionConverters._
final case class ListGameServersRequest(
    gameServerGroupName: GameServerGroupNameOrArn,
    sortOrder: Option[zio.aws.gamelift.model.SortOrder] = None,
    limit: Option[PositiveInteger] = None,
    nextToken: Option[NonZeroAndMaxString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.ListGameServersRequest = {
    import ListGameServersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.ListGameServersRequest
      .builder()
      .gameServerGroupName(
        GameServerGroupNameOrArn.unwrap(gameServerGroupName): java.lang.String
      )
      .optionallyWith(sortOrder.map(value => value.unwrap))(_.sortOrder)
      .optionallyWith(
        limit.map(value => PositiveInteger.unwrap(value): Integer)
      )(_.limit)
      .optionallyWith(
        nextToken.map(value =>
          NonZeroAndMaxString.unwrap(value): java.lang.String
        )
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.ListGameServersRequest.ReadOnly =
    zio.aws.gamelift.model.ListGameServersRequest.wrap(buildAwsValue())
}
object ListGameServersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.ListGameServersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.ListGameServersRequest =
      zio.aws.gamelift.model.ListGameServersRequest(
        gameServerGroupName,
        sortOrder.map(value => value),
        limit.map(value => value),
        nextToken.map(value => value)
      )
    def gameServerGroupName: GameServerGroupNameOrArn
    def sortOrder: Option[zio.aws.gamelift.model.SortOrder]
    def limit: Option[PositiveInteger]
    def nextToken: Option[NonZeroAndMaxString]
    def getGameServerGroupName: ZIO[Any, Nothing, GameServerGroupNameOrArn] =
      ZIO.succeed(gameServerGroupName)
    def getSortOrder: ZIO[Any, AwsError, zio.aws.gamelift.model.SortOrder] =
      AwsError.unwrapOptionField("sortOrder", sortOrder)
    def getLimit: ZIO[Any, AwsError, PositiveInteger] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, NonZeroAndMaxString] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.ListGameServersRequest
  ) extends zio.aws.gamelift.model.ListGameServersRequest.ReadOnly {
    override val gameServerGroupName: GameServerGroupNameOrArn =
      zio.aws.gamelift.model.primitives
        .GameServerGroupNameOrArn(impl.gameServerGroupName())
    override val sortOrder: Option[zio.aws.gamelift.model.SortOrder] = scala
      .Option(impl.sortOrder())
      .map(value => zio.aws.gamelift.model.SortOrder.wrap(value))
    override val limit: Option[PositiveInteger] = scala
      .Option(impl.limit())
      .map(value => zio.aws.gamelift.model.primitives.PositiveInteger(value))
    override val nextToken: Option[NonZeroAndMaxString] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.gamelift.model.primitives.NonZeroAndMaxString(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.ListGameServersRequest
  ): zio.aws.gamelift.model.ListGameServersRequest.ReadOnly = new Wrapper(impl)
}
